use std::io;
use std::io::Write;

#[allow(dead_code)]
struct Random {
    state: u64,
}

impl Random {
    fn next(&mut self) -> u64 {
        let mut x = self.state;
        x ^= x << 13;
        x ^= x >> 7;
        x ^= x << 17;
        self.state = x;
        x
    }

    #[allow(dead_code)]
    fn next_in_range(&mut self, from: usize, to: usize) -> usize {
        assert!(from < to);
        (from as u64 + self.next() % ((to - from) as u64)) as usize
    }

    #[allow(dead_code)]
    fn next_double(&mut self) -> f64 {
        (self.next() as f64) / (std::usize::MAX as f64)
    }

    #[allow(dead_code)]
    fn new(seed: u64) -> Self {
        assert_ne!(seed, 0);
        Self { state: seed }
    }
}

/**************************************************

   END OF TEMPLATE CODE

*************************************************/

const MAX_DEG: usize = 10;

const SZ: i64 = 10;
const SZM1: i64 = 9;

struct Poly {
    coefs: Vec<Vec<i64>>,
}

impl Poly {
    fn new_rand(rnd: &mut Random) -> Self {
        loop {
            let deg_x = rnd.next_in_range(1, MAX_DEG);
            let deg_y = rnd.next_in_range(1, MAX_DEG);
            let poly = Poly {
                coefs: (0..deg_x)
                    .map(|_| {
                        (0..deg_y)
                            .map(|_| rnd.next_in_range(0, 10) as i64 - 5)
                            .collect()
                    })
                    .collect(),
            };
            if poly.is_valid() {
                return poly;
            }
        }
    }

    fn is_valid(&self) -> bool {
        const MAX_VAL: i64 = 1e9 as i64;
        for x in -SZ..=SZ {
            for y in -SZ..=SZ {
                let val = self.calc(x, y);
                if val.abs() > MAX_VAL {
                    return false;
                }
            }
        }
        true
    }

    fn calc(&self, x: i64, y: i64) -> i64 {
        let mut sum = 0;
        for pw_x in 0..self.coefs.len() {
            for pw_y in 0..self.coefs[pw_x].len() {
                sum += x.pow(pw_x as u32) * y.pow(pw_y as u32) * self.coefs[pw_x][pw_y];
            }
        }
        sum
    }

    fn has_min_max(&self, satisfy: fn(i64, i64) -> bool) -> bool {
        let mut cnt = 0;
        for x in -SZM1..=SZM1 {
            for y in -SZM1..=SZM1 {
                let mut all_ok = true;
                for dx in -1..=1i64 {
                    for dy in -1..=1i64 {
                        if dx.abs() + dy.abs() == 1 {
                            if !satisfy(self.calc(x, y), self.calc(x + dx, y + dy)) {
                                all_ok = false;
                            }
                        }
                    }
                }
                if all_ok {
                    cnt += 1;
                }
            }
        }
        return cnt >= 2;
    }

    fn has_plateau(&self) -> bool {
        for x in -SZ..=SZ {
            for y in -SZ..=SZ {
                if x + 1 <= SZ && self.calc(x, y) == self.calc(x + 1, y) {
                    return true;
                }
                if y + 1 <= SZ && self.calc(x, y) == self.calc(x, y + 1) {
                    return true;
                }
            }
        }
        false
    }

    fn meet_requirements(&self, req: &Requirements) -> bool {
        if req.need_maxima != self.has_min_max(|a, b| a > b) {
            return false;
        }
        if req.need_minima != self.has_min_max(|a, b| a < b) {
            return false;
        }
        if req.need_plateau != self.has_plateau() {
            return false;
        }
        true
    }

    fn convert_to_notation(&self) -> Vec<String> {
        let mut res = vec!["0".to_owned()];
        for pw_x in 0..self.coefs.len() {
            for pw_y in 0..self.coefs[pw_x].len() {
                res.push("x".to_owned());
                res.push(pw_x.to_string());
                res.push("^".to_owned());
                res.push("y".to_owned());
                res.push(pw_y.to_string());
                res.push("^".to_owned());
                res.push(self.coefs[pw_x][pw_y].to_string());
                res.push("*".to_owned());
                res.push("*".to_owned());
                res.push("+".to_owned());
            }
        }
        res
    }
}

#[derive(Debug, Copy, Clone)]
struct Requirements {
    need_maxima: bool,
    need_minima: bool,
    need_plateau: bool,
}

fn find_poly(req: Requirements) -> Poly {
    let mut rnd = Random::new(787788);
    loop {
        let poly = Poly::new_rand(&mut rnd);
        if poly.meet_requirements(&req) {
            return poly;
        }
    }
}

fn stress() {
    let bools = vec![false, true];
    for &need_maxima in bools.iter() {
        for &need_minima in bools.iter() {
            for &need_plateau in bools.iter() {
                let req = Requirements {
                    need_plateau,
                    need_minima,
                    need_maxima,
                };
                let poly = find_poly(req);
                dbg!(req, "found!!!");
            }
        }
    }
}

pub fn main() {
    let stdout = io::stdout();
    let mut out = std::io::BufWriter::new(stdout.lock());
    let parse = || -> bool {
        let mut line = String::new();
        std::io::stdin().read_line(&mut line).unwrap();
        line.trim().ends_with("Yes")
    };
    let need_maxima = parse();
    let need_minima = parse();
    let need_plateau = parse();
    let req = Requirements {
        need_maxima,
        need_minima,
        need_plateau,
    };
    let poly = find_poly(req);
    for word in poly.convert_to_notation().iter() {
        write!(out, "{} ", word).unwrap();
    }
}
